Bug 527378 - Stop supporting old update manager for launching Deprecate
TargetPlatform.createPlatformConfiguration and mark it as noreference.

Change-Id: Ic0d90b7b4ad560421a711d0a43604805c38f0f46
Alexander Kurtakov <akurtako@redhat.com>
diff --git a/ui/org.eclipse.pde.core/.settings/.api_filters b/ui/org.eclipse.pde.core/.settings/.api_filters
index 5d17ac3..0845ee0 100644
--- a/ui/org.eclipse.pde.core/.settings/.api_filters
+++ b/ui/org.eclipse.pde.core/.settings/.api_filters
@@ -1,5 +1,21 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
 <component id="org.eclipse.pde.core" version="2">
+    <resource path="META-INF/MANIFEST.MF">
+        <filter comment="Stop supporting old update manager for launching" id="926941240">
+            <message_arguments>
+                <message_argument value="3.12.0"/>
+                <message_argument value="3.11.100"/>
+            </message_arguments>
+        </filter>
+    </resource>
+    <resource path="src/org/eclipse/pde/core/plugin/TargetPlatform.java" type="org.eclipse.pde.core.plugin.TargetPlatform">
+        <filter comment="Old Update Manager is planned for removal and so it this API.  See bug 527378 for details" id="338944126">
+            <message_arguments>
+                <message_argument value="org.eclipse.pde.core.plugin.TargetPlatform"/>
+                <message_argument value="createPlatformConfiguration(File, IPluginModelBase[], IPluginModelBase)"/>
+            </message_arguments>
+    </filter>
+    </resource>
     <resource path="src/org/eclipse/pde/internal/core/project/BundleProjectService.java" type="org.eclipse.pde.internal.core.project.BundleProjectService">
         <filter comment="Platform Team allows use of bundle importers for PDE import from source repository" id="640712815">
             <message_arguments>
diff --git a/ui/org.eclipse.pde.core/src/org/eclipse/pde/core/plugin/TargetPlatform.java b/ui/org.eclipse.pde.core/src/org/eclipse/pde/core/plugin/TargetPlatform.java
index f328076..0f59890 100644
--- a/ui/org.eclipse.pde.core/src/org/eclipse/pde/core/plugin/TargetPlatform.java
+++ b/ui/org.eclipse.pde.core/src/org/eclipse/pde/core/plugin/TargetPlatform.java
@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2007, 2013 IBM Corporation and others.
+ *  Copyright (c) 2007, 2018 IBM Corporation and others.
  *  All rights reserved. This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License v1.0
  *  which accompanies this distribution, and is available at
@@ -246,14 +246,22 @@
 	 * Creates a platform configuration to be used when launching an Eclipse
 	 * application that uses Update Manager as a configurator
 	 *
-	 * @param location the location where the configuration should be persisted
-	 * @param plugins the list of plug-ins that make up the configuration
-	 * @param brandingPlugin  if specified, a entry for the feature containing the branding plug-in will
-	 * 					be created in the platform configuration
+	 * @param location
+	 *            the location where the configuration should be persisted
+	 * @param plugins
+	 *            the list of plug-ins that make up the configuration
+	 * @param brandingPlugin
+	 *            if specified, a entry for the feature containing the branding
+	 *            plug-in will be created in the platform configuration
 	 *
 	 * @throws CoreException an exception is thrown if there was a problem writing the platform
 	 * 			configuration file
 	 */
+	@Deprecated
 	public static void createPlatformConfiguration(File location, IPluginModelBase[] plugins, IPluginModelBase brandingPlugin) throws CoreException {
 		UpdateManagerHelper.createPlatformConfiguration(location, plugins, brandingPlugin);
 	}
@@ -246,14 +246,22 @@
 	 *
-	 * @throws CoreException an exception is thrown if there was a problem writing the platform
-	 * 			configuration file
+	 * @throws CoreException
+	 *             an exception is thrown if there was a problem writing the
+	 *             platform configuration file
+	 * @deprecated Old Update Manager is planned for removal and so it this API.
+	 * @noreference Old Update Manager is planned for removal and so it this API.
+	 *              See bug 527378 for details.
 	 */